C$$$  SUBPROGRAM DOCUMENTATION BLOCK
C                .      .    .                                       .
C SUBPROGRAM:    M_INTHT     INTERPOLATE RAOB HEIGHTS -- HYDRO EQ.
C   PRGMMR: M. BARTH         ORG: FSL        DATE: 00-02-11
C
C ABSTRACT: USE THE HYDROSTATIC EQUATION TO INTERPOLATE MISSING HEIGHTS
C   FROM LEVELS THAT DO HAVE TEMPERATURES.  ANY LEVEL TYPE IS USED
C   (ALTHOUGH FOR BEST RESULTS, SIG LEVELS SHOULD BE AVAILABLE).
C
C PROGRAM HISTORY LOG:
C   00-02-11  M. BARTH    ORIGINAL VERSION
C   08-06-13  L. BENJAMIN CHANGED "MADISCON" INCLUDE TO 
C                         "INTQC1CON1".  
C
C USAGE:    CALL M_INTHT (I,NLEVELS,P,T,HT)
C
C   INPUT ARGUMENT LIST:
C     I        - I       INDEX OF THE LEVEL TO BE INTERPOLATED
C     NLEVELS  - I       NUMBER OF LEVELS IN DATA ARRAYS
C     P        - RA      PRESSURES
C     T        - RA      TEMPERATURES
C
C   INPUT/OUTPUT ARGUMENT LIST:
C     HT       - RA      HEIGHTS
C
C SUBPROGRAMS CALLED:
C     NONE
C
C REMARKS:
C     THE INTERPOLATION ALGORITHM USED IS FROM THE FSL RADIOSONDE
C     DATABASE PROJECT.
C
C ATTRIBUTES:
C   LANGUAGE: FORTRAN-77 + EXTENSIONS
C   MACHINE:  UNIX
C$$$

      SUBROUTINE M_INTHT(I,NLEVELS,P,T,HT)

C     ------------------------------------------------------------------
C     INCLUDES AND COMMONS
C     ------------------------------------------------------------------
      INCLUDE 'IMPLICIT'
      INCLUDE 'INTQC1CON1'

C     ------------------------------------------------------------------
C     ARGUMENTS
C     ------------------------------------------------------------------
      INTEGER I,NLEVELS
      REAL P(*)
      REAL T(*)
      REAL HT(*)

C     ------------------------------------------------------------------
C     LOCAL
C     ------------------------------------------------------------------
      INTEGER PNT1,J,TMP
      REAL A,B,C


C     *****************************************************************
C     ******************* BEGIN OF M_INTHT ****************************
C     *****************************************************************

C     ------------------------------------------------------------------
C     INITIALIZE THE DIFFERENCE VARIABLE
C     ------------------------------------------------------------------
      PNT1 = MISS_P

C     ------------------------------------------------------------------
C     FIND THE CLOSEST HEIGHT LEVEL TO TARGET.
C     ------------------------------------------------------------------
      DO 20 J = 1, NLEVELS

         IF(J.EQ.I)GO TO 20

         IF(HT(J).NE.MISS_P.AND.P(J).NE.MISS_P)THEN

	    IF(P(J)-P(I).GE.0.AND.P(J)-P(I).LT.PNT1)THEN

               IF(T(J).NE.MISS_P)THEN
                  TMP = J
                  PNT1 = P(J) - P(I)
               ENDIF

	    ENDIF

         ENDIF

 20   CONTINUE

C     ------------------------------------------------------------------
C     IF A SUITABLE LEVEL WASN'T FOUND, SKIP IT.
C     ------------------------------------------------------------------
      IF(PNT1.EQ.MISS_P)GO TO 900

C     ------------------------------------------------------------------
C     COMPUTE THE MISSING HEIGHT USING THE HYDROSTATIC EQUATION.
C     ------------------------------------------------------------------
      A = P(TMP)/P(I)
      B = 14.6 * LOG(A)
      C = T(I) + T(TMP)
      HT(I) = B * C + HT(TMP)
      IF(HT(I).GT.99999)HT(I) = MISS_P

 900  RETURN
      END


C**---------------------------------------------------------------------
C**REQUIRED STANDARD FSL DISCLAIMER (NOVEMBER 2000)
C**---------------------------------------------------------------------
C**  OPEN SOURCE LICENSE/DISCLAIMER,  FORECAST SYSTEMS LABORATORY
C**  NOAA/OAR/FSL, 325 BROADWAY BOULDER, CO 80305
C**
C**  THIS SOFTWARE IS DISTRIBUTED UNDER THE OPEN SOURCE DEFINITION, 
C**  WHICH MAY BE FOUND AT http://www.opensource.org/osd.html.
C**
C**  IN PARTICULAR, REDISTRIBUTION AND USE IN SOURCE AND BINARY FORMS,
C**  WITH OR WITHOUT MODIFICATION, ARE PERMITTED PROVIDED THAT THE 
C**  FOLLOWING CONDITIONS ARE MET:
C**
C**  - REDISTRIBUTIONS OF SOURCE CODE MUST RETAIN THIS NOTICE, THIS LIST
C**    OF CONDITIONS AND THE FOLLOWING DISCLAIMER.
C**
C**  - REDISTRIBUTIONS IN BINARY FORM MUST PROVIDE ACCESS TO THIS 
C**    NOTICE, THIS LIST OF CONDITIONS AND THE FOLLOWING DISCLAIMER, AND
C**    THE UNDERLYING SOURCE CODE.
C**
C**  - ALL MODIFICATIONS TO THIS SOFTWARE MUST BE CLEARLY DOCUMENTED, 
C**    AND ARE SOLELY THE RESPONSIBILITY OF THE AGENT MAKING THE 
C**    MODIFICATIONS.
C**
C**  - IF SIGNIFICANT MODIFICATIONS OR ENHANCEMENTS ARE MADE TO THIS
C**    SOFTWARE, THE FSL SOFTWARE POLICY MANAGER 
C**    (softwaremgr.fsl@noaa.gov) BE NOTIFIED.
C**
C**  THIS SOFTWARE AND ITS DOCUMENTATION ARE IN THE PUBLIC DOMAIN AND 
C**  ARE FURNISHED "AS IS."  THE AUTHORS, THE UNITED STATES GOVERNMENT,
C**  ITS INSTRUMENTALITIES, OFFICERS, EMPLOYEES, AND AGENTS MAKE NO 
C**  WARRANTY, EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE SOFTWARE
C**  AND DOCUMENTATION FOR ANY PURPOSE.  THEY ASSUME NO RESPONSIBILITY 
C**  (1) FOR THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO 
C**  PROVIDE TECHNICAL SUPPORT TO USERS.
C**---------------------------------------------------------------------
